import ModalFactory from 'core/modal_factory';
import ModalEvents from 'core/modal_events';
import {activityHasStartedReports} from './repository';

export const init = (title, messageWithReport, messageWithoutReport) => {
    /**
     * Shows a modal cancel dialog
     * @param {string} title
     * @param {string} message
     * @param {callback} callback
     * @param {string} type type of modal to create
     * @return {modal}
     */
    async function cancelDialog(title, message, callback, type) {
        const modal = await ModalFactory.create({
            type,
            title: title,
            body: message,
        });
        await modal.show();
        if (callback) {
            modal.getRoot().on(ModalEvents.delete, callback);
        }
        return modal;
    }

    /**
     * Handles a delete request on a LabNbook activity.
     * @param {Event} evt
     * @param {DOMElement} elem
     */
    async function deleteHandler(evt, elem) {
        if (deleteHandler.shouldPrevent) {
            evt.preventDefault();
            evt.stopPropagation();
            let activityID = elem.getAttribute('data-id');
            if (!activityID) {
                activityID = new URLSearchParams(elem.getAttribute('href')).get('delete');
            }
            const hasStartedReports = await activityHasStartedReports(activityID);
            if (hasStartedReports) {
                await cancelDialog(
                    title,
                    messageWithReport,
                    null,
                    ModalFactory.types.CANCEL
                );
            } else {
                await cancelDialog(
                    title,
                    messageWithoutReport,
                    function() {
                        // Re run event without interception
                        deleteHandler.shouldPrevent = false;
                        elem.dispatchEvent(evt);
                    },
                    ModalFactory.types.DELETE_CANCEL
                );
            }
        } else {
            deleteHandler.shouldPrevent = true;
        }
    }
    deleteHandler.shouldPrevent = true;
    document.querySelectorAll('li.labnbook .editing_delete').forEach(function(elem) {
         elem.addEventListener('click', async function(evt) {
             deleteHandler(evt, elem);
         });
     });
};
